@@ -26,7 +26,6 @@
 #include <grub/misc.h>
 #include <grub/mm.h>
 #include <grub/err.h>
-#include <grub/dl.h>
 #include <grub/charset.h>
 
 #define GRUB_FAT_DIR_ENTRY_SIZE	32
@@ -156,8 +155,6 @@ struct grub_fat_data
   grub_uint32_t uuid;
 };
 
-static grub_dl_t my_mod;
-
 static int
 fat_log2 (unsigned x)
 {
@@ -381,7 +378,7 @@ grub_fat_read_data (grub_disk_t disk, struct grub_fat_data *data,
 			  + data->logical_sector_bits
 			  + GRUB_DISK_SECTOR_BITS);
   logical_cluster = offset >> logical_cluster_bits;
-  offset &= (1 << logical_cluster_bits) - 1;
+  offset &= (1ULL << logical_cluster_bits) - 1;
 
   if (logical_cluster < data->cur_cluster_num)
     {
@@ -725,8 +722,6 @@ grub_fat_dir (grub_device_t device, const char *path,
   char *dirname = 0;
   char *p;
 
-  grub_dl_ref (my_mod);
-
   data = grub_fat_mount (disk);
   if (! data)
     goto fail;
@@ -754,8 +749,6 @@ grub_fat_dir (grub_device_t device, const char *path,
   grub_free (dirname);
   grub_free (data);
 
-  grub_dl_unref (my_mod);
-
   return grub_errno;
 }
 
@@ -765,8 +758,6 @@ grub_fat_open (grub_file_t file, const char *name)
   struct grub_fat_data *data = 0;
   char *p = (char *) name;
 
-  grub_dl_ref (my_mod);
-
   data = grub_fat_mount (file->device->disk);
   if (! data)
     goto fail;
@@ -794,8 +785,6 @@ grub_fat_open (grub_file_t file, const char *name)
 
   grub_free (data);
 
-  grub_dl_unref (my_mod);
-
   return grub_errno;
 }
 
@@ -812,8 +801,6 @@ grub_fat_close (grub_file_t file)
 {
   grub_free (file->data);
 
-  grub_dl_unref (my_mod);
-
   return grub_errno;
 }
 
@@ -837,8 +824,6 @@ grub_fat_label (grub_device_t device, char **label)
   struct grub_fat_data *data;
   grub_disk_t disk = device->disk;
 
-  grub_dl_ref (my_mod);
-
   data = grub_fat_mount (disk);
   if (! data)
     goto fail;
@@ -855,8 +840,6 @@ grub_fat_label (grub_device_t device, char **label)
 
  fail:
 
-  grub_dl_unref (my_mod);
-
   grub_free (data);
 
   return grub_errno;
@@ -868,8 +851,6 @@ grub_fat_uuid (grub_device_t device, char **uuid)
   struct grub_fat_data *data;
   grub_disk_t disk = device->disk;
 
-  grub_dl_ref (my_mod);
-
   data = grub_fat_mount (disk);
   if (data)
     {
@@ -880,8 +861,6 @@ grub_fat_uuid (grub_device_t device, char **uuid)
   else
     *uuid = NULL;
 
-  grub_dl_unref (my_mod);
-
   grub_free (data);
 
   return grub_errno;
